# Yoti connection

The Yoti connection acts as a wrapper of the Yoti SDK.

## Usage

The connection is used in conjunction with the `fetchai/yoti` protocol.

For an example of its usage check out this repo: https://github.com/fetchai/agents-yoti
